@@ -1,9 +1,9 @@
 /*
- *  $Id: buttons.c,v 1.107 2021/12/13 22:17:56 tom Exp $
+ *  $Id: buttons.c,v 1.109 2022/04/05 23:45:54 tom Exp $
  *
  *  buttons.c -- draw buttons, e.g., OK/Cancel
  *
- *  Copyright 2000-2020,2021	Thomas E. Dickey
+ *  Copyright 2000-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -21,13 +21,9 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#ifdef NEED_WCHAR_H
-#include <wchar.h>
-#endif
-
 #define MIN_BUTTON (-dialog_state.visit_cols)
 #define CHR_BUTTON (!dialog_state.plain_buttons)
 
@@ -604,7 +600,7 @@ finish_ok_label(const char **labels, int n)
     if (n == 0) {
 	labels[n++] = my_ok_label();
 	dialog_vars.nook = FALSE;
-	dlg_trace_msg("# ignore --nook, since at least one button is needed\n");
+	DLG_TRACE(("# ignore --nook, since at least one button is needed\n"));
     }
 
     labels[n] = NULL;
