@@ -1,9 +1,9 @@
 /*
- * $Id: calendar.c,v 1.106 2020/11/23 09:03:49 tom Exp $
+ * $Id: calendar.c,v 1.110 2022/04/03 22:38:16 tom Exp $
  *
  *  calendar.c -- implements the calendar box
  *
- *  Copyright 2001-2019,2020	Thomas E. Dickey
+ *  Copyright 2001-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,14 +24,6 @@
 #include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#include <time.h>
-
-#ifdef HAVE_STDINT_H
-#include <stdint.h>
-#else
-#define intptr_t long
-#endif
-
 #define ONE_DAY  (60 * 60 * 24)
 
 #define MON_WIDE 4		/* width of a month-name */
@@ -748,7 +740,7 @@ dialog_calendar(const char *title,
     now_time = time((time_t *) 0);
     current = *localtime(&now_time);
 
-#if HAVE_MKTIME
+#ifdef HAVE_MKTIME
     current.tm_isdst = -1;
     if (year >= 1900) {
 	current.tm_year = year - 1900;
@@ -757,7 +749,7 @@ dialog_calendar(const char *title,
 	current.tm_mon = month - 1;
     }
     if (day > 0 && day <= days_per_month(current.tm_year + 1900,
-					 current.tm_mon + 1)) {
+					 current.tm_mon)) {
 	current.tm_mday = day;
     }
     now_time = mktime(&current);
