@@ -1,9 +1,9 @@
 /*
- *  $Id: checklist.c,v 1.162 2019/08/05 09:14:59 tom Exp $
+ *  $Id: checklist.c,v 1.170 2022/04/04 22:25:11 tom Exp $
  *
  *  checklist.c -- implements the checklist box
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2020,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -26,7 +26,7 @@
  *	Alessandro Rubini - rubini@ipvvis.unipv.it: merged the two
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
 #define MIN_HIGH  (1 + (5 * MARGIN))
@@ -98,18 +98,20 @@ print_item(ALL_DATA * data,
 }
 
 static void
-print_list(ALL_DATA * data, int choice, int scrollamt, int max_choice)
+print_list(ALL_DATA * data, int choice, int scrollamt, int max_choice, int max_items)
 {
     int i;
     int cur_y, cur_x;
 
     getyx(data->dialog, cur_y, cur_x);
     for (i = 0; i < max_choice; i++) {
-	print_item(data,
-		   data->list,
-		   &data->items[i + scrollamt],
-		   data->states,
-		   i, i == choice);
+	int ii = i + scrollamt;
+	if (ii < max_items)
+	    print_item(data,
+		       data->list,
+		       &data->items[ii],
+		       data->states,
+		       i, i == choice);
     }
     (void) wnoutrefresh(data->list);
 
@@ -192,12 +194,11 @@ dlg_checklist(const char *title,
 #endif
     ALL_DATA all;
     int i, j, key2, found, x, y, cur_x, cur_y;
-    int key = 0, fkey;
+    int key, fkey;
     int button = dialog_state.visit_items ? -1 : dlg_default_button();
     int choice = dlg_default_listitem(items);
     int scrollamt = 0;
     int max_choice;
-    int was_mouse;
     int use_width, list_width, name_width, text_width;
     int result = DLG_EXIT_UNKNOWN;
     int num_states;
@@ -304,8 +305,7 @@ dlg_checklist(const char *title,
      * After displaying the prompt, we know how much space we really have.
      * Limit the list to avoid overwriting the ok-button.
      */
-    if (all.use_height + MIN_HIGH > height - cur_y)
-	all.use_height = height - MIN_HIGH - cur_y;
+    all.use_height = height - MIN_HIGH - cur_y;
     if (all.use_height <= 0)
 	all.use_height = 1;
 
@@ -369,7 +369,7 @@ dlg_checklist(const char *title,
 	scrollamt = MAX(0, choice - max_choice + 1);
 	choice = max_choice - 1;
     }
-    print_list(&all, choice, scrollamt, max_choice);
+    print_list(&all, choice, scrollamt, max_choice, item_no);
 
     /* register the new window, along with its borders */
     dlg_mouse_mkbigregion(all.box_y + 1, all.box_x,
@@ -379,7 +379,10 @@ dlg_checklist(const char *title,
     dlg_draw_buttons(dialog, height - 2, 0, buttons, button, FALSE, width);
 
     dlg_trace_win(dialog);
+
     while (result == DLG_EXIT_UNKNOWN) {
+	int was_mouse;
+
 	if (button < 0)		/* --visit-items */
 	    wmove(dialog, all.box_y + choice + 1, all.box_x + all.check_x + 2);
 
@@ -398,7 +401,7 @@ dlg_checklist(const char *title,
 	    i = (key - KEY_MAX);
 	    if (i < max_choice) {
 		choice = (key - KEY_MAX);
-		print_list(&all, choice, scrollamt, max_choice);
+		print_list(&all, choice, scrollamt, max_choice, item_no);
 
 		key = DLGK_TOGGLE;	/* force the selected item to toggle */
 	    } else {
@@ -448,7 +451,7 @@ dlg_checklist(const char *title,
 		    (void) wmove(dialog, cur_y, cur_x);
 		} else {
 		    items[current].state = 1;
-		    print_list(&all, choice, scrollamt, max_choice);
+		    print_list(&all, choice, scrollamt, max_choice, item_no);
 		}
 	    }
 	    continue;		/* wait for another key press */
@@ -548,10 +551,10 @@ dlg_checklist(const char *title,
 			choice = max_choice - 1;
 			scrollamt += (i - max_choice + 1);
 		    }
-		    print_list(&all, choice, scrollamt, max_choice);
+		    print_list(&all, choice, scrollamt, max_choice, item_no);
 		} else {
 		    choice = i;
-		    print_list(&all, choice, scrollamt, max_choice);
+		    print_list(&all, choice, scrollamt, max_choice, item_no);
 		}
 	    }
 	    continue;		/* wait for another key press */
@@ -562,6 +565,9 @@ dlg_checklist(const char *title,
 	    case DLGK_ENTER:
 		result = dlg_enter_buttoncode(button);
 		break;
+	    case DLGK_LEAVE:
+		result = dlg_ok_buttoncode(button);
+		break;
 	    case DLGK_FIELD_PREV:
 		button = dlg_prev_button(buttons, button);
 		dlg_draw_buttons(dialog, height - 2, 0, buttons, button,
@@ -579,9 +585,10 @@ dlg_checklist(const char *title,
 		height = old_height;
 		width = old_width;
 		free(prompt);
-		dlg_clear();
-		dlg_del_window(dialog);
-		dlg_mouse_free_regions();
+		_dlg_resize_cleanup(dialog);
+		/* keep position */
+		choice += scrollamt;
+		scrollamt = 0;
 		/* repaint */
 		goto retry;
 #endif
