@@ -1,9 +1,9 @@
 /*
- *  $Id: progressbox.c,v 1.54 2020/11/22 15:48:27 tom Exp $
+ *  $Id: progressbox.c,v 1.55 2022/04/03 22:38:16 tom Exp $
  *
  *  progressbox.c -- implements the progress box
  *
- *  Copyright 2006-2019,2020	Thomas E. Dickey
+ *  Copyright 2006-2020,2022	Thomas E. Dickey
  *  Copyright 2005		Valery Reznic
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -22,13 +22,9 @@
  *	Boston, MA 02110, USA.
  */
 
-#include <dialog.h>
+#include <dlg_internals.h>
 #include <dlg_keys.h>
 
-#ifdef KEY_RESIZE
-#include <errno.h>
-#endif
-
 #define MIN_HIGH (4)
 #define MIN_WIDE (10 + 2 * (2 + MARGIN))
 
