@@ -1,9 +1,9 @@
 /*
- *  $Id: treeview.c,v 1.37 2019/08/08 23:47:23 tom Exp $
+ *  $Id: treeview.c,v 1.46 2022/04/05 00:15:15 tom Exp $
  *
  *  treeview.c -- implements the treeview dialog
  *
- *  Copyright 2012-2018,2019	Thomas E. Dickey
+ *  Copyright 2012-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -101,7 +101,8 @@ static void
 print_list(ALL_DATA * data,
 	   int choice,
 	   int scrollamt,
-	   int max_choice)
+	   int max_choice,
+	   int max_items)
 {
     int i;
     int cur_y, cur_x;
@@ -109,11 +110,13 @@ print_list(ALL_DATA * data,
     getyx(data->dialog, cur_y, cur_x);
 
     for (i = 0; i < max_choice; i++) {
-	print_item(data,
-		   &data->items[scrollamt + i],
-		   data->states,
-		   data->depths[scrollamt + i],
-		   i, i == choice);
+	int ii = i + scrollamt;
+	if (ii < max_items)
+	    print_item(data,
+		       &data->items[ii],
+		       data->states,
+		       data->depths[ii],
+		       i, i == choice);
     }
     (void) wnoutrefresh(data->list);
 
@@ -196,12 +199,11 @@ dlg_treeview(const char *title,
 #endif
     ALL_DATA all;
     int i, j, key2, found, x, y, cur_y, box_x, box_y;
-    int key = 0, fkey;
+    int key, fkey;
     int button = dialog_state.visit_items ? -1 : dlg_default_button();
     int choice = dlg_default_listitem(items);
     int scrollamt = 0;
     int max_choice;
-    int was_mouse;
     int use_height;
     int use_width, name_width, text_width, tree_width;
     int result = DLG_EXIT_UNKNOWN;
@@ -291,8 +293,7 @@ dlg_treeview(const char *title,
      * After displaying the prompt, we know how much space we really have.
      * Limit the list to avoid overwriting the ok-button.
      */
-    if (use_height + MIN_HIGH > height - cur_y)
-	use_height = height - MIN_HIGH - cur_y;
+    use_height = height - MIN_HIGH - cur_y;
     if (use_height <= 0)
 	use_height = 1;
 
@@ -352,12 +353,17 @@ dlg_treeview(const char *title,
     all.box_y = box_y;
     all.use_height = use_height;
     all.list = list;
-    print_list(&all, choice, scrollamt, max_choice);
+#define PrintList() \
+    print_list(&all, choice, scrollamt, max_choice, item_no)
+    PrintList();
 
     dlg_draw_buttons(dialog, height - 2, 0, buttons, button, FALSE, width);
 
     dlg_trace_win(dialog);
+
     while (result == DLG_EXIT_UNKNOWN) {
+	int was_mouse;
+
 	if (button < 0)		/* --visit-items */
 	    wmove(dialog, box_y + choice + 1, box_x + all.check_x + 2);
 
@@ -375,7 +381,7 @@ dlg_treeview(const char *title,
 	    i = (key - KEY_MAX);
 	    if (i < max_choice) {
 		choice = (key - KEY_MAX);
-		print_list(&all, choice, scrollamt, max_choice);
+		PrintList();
 
 		key = DLGK_TOGGLE;	/* force the selected item to toggle */
 	    } else {
@@ -411,7 +417,7 @@ dlg_treeview(const char *title,
 		    items[current].state = 1;
 		}
 	    }
-	    print_list(&all, choice, scrollamt, max_choice);
+	    PrintList();
 	    continue;		/* wait for another key press */
 	}
 
@@ -508,10 +514,10 @@ dlg_treeview(const char *title,
 			choice = max_choice - 1;
 			scrollamt += (i - max_choice + 1);
 		    }
-		    print_list(&all, choice, scrollamt, max_choice);
+		    PrintList();
 		} else {
 		    choice = i;
-		    print_list(&all, choice, scrollamt, max_choice);
+		    PrintList();
 		}
 	    }
 	    continue;		/* wait for another key press */
@@ -522,6 +528,9 @@ dlg_treeview(const char *title,
 	    case DLGK_ENTER:
 		result = dlg_enter_buttoncode(button);
 		break;
+	    case DLGK_LEAVE:
+		result = dlg_ok_buttoncode(button);
+		break;
 	    case DLGK_FIELD_PREV:
 		button = dlg_prev_button(buttons, button);
 		dlg_draw_buttons(dialog, height - 2, 0, buttons, button,
@@ -539,10 +548,10 @@ dlg_treeview(const char *title,
 		height = old_height;
 		width = old_width;
 		/* repaint */
-		dlg_clear();
-		dlg_del_window(dialog);
-		refresh();
-		dlg_mouse_free_regions();
+		_dlg_resize_cleanup(dialog);
+		/* keep position */
+		choice += scrollamt;
+		scrollamt = 0;
 		goto retry;
 #endif
 	    default:
